local L = LibStub("AceLocale-3.0"):GetLocale("GigaItemAuction", false)

local _G				= getfenv(0)

local pairs			    = _G.pairs
local ipairs			= _G.ipairs
local select			= _G.select

local table_insert		= _G.table.insert
local table_remove		= _G.table.remove
local table_sort		= _G.table.sort

local anchorAdmin 		= "GIAAdminFrame"

local PLAYERNAME 		= UnitName("player")
local _, PLAYERCLASS 	= UnitClass("player")
local PLAYERGUID 		= 0

local db

local function getGameTimeAsUnix()
	return time()
end

local trueAdminRanks = {
	[0] = true,
	[1] = true,
	[2] = true,
	[3] = true,
}

local function getCurrentDate(timestamp, short)
   local dt = date("*t", timestamp)
   if short then
      return string.format("%02d:%02d:%02d", dt.hour, dt.min, dt.sec)
   else
      return string.format("%02d/%02d/%d - %02d:%02d:%02d", dt.day , dt.month, dt.year, dt.hour, dt.min, dt.sec)
   end
end

function GigaItemAuction:ADMINOnInitialize()
	db 			= self.db.profile
end

function GigaItemAuction:CreateADMINFrame()
	PLAYERGUID 	= tonumber(UnitGUID("player"), 16)

	if self.ADMINFrame then return end
	
	local dbn = db.nowAuction
	local dbc = db.config
	local dba = db.admin
	
	local sfont = "Interface\\AddOns\\GigaItemAuction\\textures\\FRIZQT__.TTF"
	
	self.ADMINFrame = CreateFrame("Frame", anchorAdmin, UIParent)
    local f = self.ADMINFrame
	local m = self.AUCTIONFrame
	
    f:SetResizable(false)
    f:SetMovable(true)
    f:SetWidth(m:GetWidth())
    f:SetHeight(115)
    f:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background",
        edgeFile =  "Interface/Tooltips/UI-Tooltip-Border",
        edgeSize= 16, insets = { left = 0, right = 0, top = 0, bottom = 0 }}) 
    f:SetBackdropColor(unpack(self.colors.black_trans))
    f:SetBackdropBorderColor(unpack(self.colors.red_trans))
    f:EnableMouse(true)
    f:ClearAllPoints()
    f:SetScript("OnMouseDown", function() f:StartMoving(); end)
    f:SetScript("OnMouseUp", function() f:StopMovingOrSizing(); end)
    f:SetPoint("TOPLEFT", m, "TOPRIGHT")
	
--~ 	Titel
	f.Title = f:CreateFontString("GIA_TitleAdmin", "HIGH")
    f.Title:SetFont(sfont,14)
    f.Title:SetText(L["AuctionControlPanel"])
    f.Title:SetPoint("TOPLEFT", f, "TOPLEFT", 10, -5)
    f.Title:SetTextColor(unpack(self.colors.yellow))
	
--~     closeButton
    f.closeButton = CreateFrame("Button", nil, f, "UIPanelCloseButton")
    f.closeButton:SetPoint("TOPRIGHT", f, "TOPRIGHT", 3, 3)
    f.closeButton:SetWidth(30)
    f.closeButton:SetHeight(30)    
    f.closeButton:SetScript("OnClick", function() self:HideADMINFrame() end)
	
--~     adminButton
    f.adminButton = CreateFrame("Button", nil, f, "UIPanelButtonTemplate")
    f.adminButton:SetPoint("RIGHT", f.closeButton, "LEFT", 5, 0)
    f.adminButton:SetWidth(16)
    f.adminButton:SetHeight(16)  
    f.adminButton:SetText("L") 
	f.adminButton:RegisterForClicks("AnyUp")
    f.adminButton:SetScript("OnClick", function() self:ToggleBIDLISTFrame() end)
	
--~ 	AktuellerAuctionAbbrechen
	f.breakTitle = f:CreateFontString("GIA_breakTitle", "HIGH")
    f.breakTitle:SetFont(sfont,14)
    f.breakTitle:SetText(L["Auction:"])
    f.breakTitle:SetPoint("TOPLEFT", f, "TOPLEFT", 10, -25)
    f.breakTitle:SetTextColor(unpack(self.colors.white))
	
--~     pauseButton
    f.pauseButton = CreateFrame("Button", nil, f, "UIPanelButtonTemplate")
    f.pauseButton:SetPoint("LEFT", f.breakTitle, "RIGHT", 5, 0)
    f.pauseButton:SetWidth(45)
    f.pauseButton:SetHeight(20)  
    f.pauseButton:SetText(L["admin_button_text_pause"]) 
	f.pauseButton:RegisterForClicks("AnyUp")
    f.pauseButton:SetScript("OnClick", function() self:SendAdminPauseAuction() end)
	f.pauseButton:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(f, "ANCHOR_TOPLEFT",0,5);
		GameTooltip:AddLine(L["tooltip_admin_pause"])
		GameTooltip:Show()
	end)
	f.pauseButton:SetScript("OnLeave", function(self) GameTooltip:Hide() end)
	f.pauseButton:Disable()
	
--~     startButton
    f.startButton = CreateFrame("Button", nil, f, "UIPanelButtonTemplate")
    f.startButton:SetPoint("LEFT", f.pauseButton, "RIGHT", 5, 0)
    f.startButton:SetWidth(45)
    f.startButton:SetHeight(20)  
    f.startButton:SetText(L["admin_button_text_start"]) 
	f.startButton:RegisterForClicks("AnyUp")
    f.startButton:SetScript("OnClick", function() self:SendAdminStartAuction() end)
	f.startButton:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(f, "ANCHOR_TOPLEFT",0,5);
		GameTooltip:AddLine(L["tooltip_admin_start"])
		GameTooltip:Show()
	end)
	f.startButton:SetScript("OnLeave", function(self) GameTooltip:Hide() end)
	f.startButton:Disable()
	
--~     resetButton
    f.resetButton = CreateFrame("Button", nil, f, "UIPanelButtonTemplate")
    f.resetButton:SetPoint("LEFT", f.startButton, "RIGHT", 5, 0)
    f.resetButton:SetWidth(45)
    f.resetButton:SetHeight(20)  
    f.resetButton:SetText(L["admin_button_text_reset"]) 
	f.resetButton:RegisterForClicks("AnyUp")
    f.resetButton:SetScript("OnClick", function() self:SendAdminResetAuction() end)
	f.resetButton:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(f, "ANCHOR_TOPLEFT",0,5);
		GameTooltip:AddLine(L["tooltip_admin_reset"])
		GameTooltip:Show()
	end)
	f.resetButton:SetScript("OnLeave", function(self) GameTooltip:Hide() end)
	f.resetButton:Disable()
	
--~     breakButton
    f.breakButton = CreateFrame("Button", nil, f, "UIPanelButtonTemplate")
    f.breakButton:SetPoint("TOPLEFT", f.pauseButton, "BOTTOMLEFT", 0, -5)
    f.breakButton:SetWidth(70)
    f.breakButton:SetHeight(20)  
    f.breakButton:SetText(L["admin_button_text_break"]) 
	f.breakButton:RegisterForClicks("AnyUp")
    f.breakButton:SetScript("OnClick", function() self:SendAdminBreak() end)
	f.breakButton:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(f, "ANCHOR_TOPLEFT",0,5);
		GameTooltip:AddLine(L["tooltip_admin_break"])
		GameTooltip:Show()
	end)
	f.breakButton:SetScript("OnLeave", function(self) GameTooltip:Hide() end)
	f.breakButton:Disable()
	
--~     aLongButton
    f.aLongButton = CreateFrame("Button", nil, f, "UIPanelButtonTemplate")
    f.aLongButton:SetPoint("LEFT", f.breakButton, "RIGHT", 5, 0)
    f.aLongButton:SetWidth(70)
    f.aLongButton:SetHeight(20)  
    f.aLongButton:SetText(L["admin_button_text_timeedit"]) 
	f.aLongButton:RegisterForClicks("AnyUp")
    f.aLongButton:SetScript("OnClick", function() self:SendAdminAuctionLonger() end)
	f.aLongButton:SetScript("OnEnter", function(self)
		GameTooltip:SetOwner(f, "ANCHOR_TOPLEFT",0,5);
		GameTooltip:AddLine(L["tooltip_admin_timeedit"])
		GameTooltip:Show()
	end)
	f.aLongButton:SetScript("OnLeave", function(self) GameTooltip:Hide() end)
	f.aLongButton:Disable()
	
	
	
	
--~ 	SliderText
	f.SliderText = f:CreateFontString("GIA_breakTitle", "HIGH")
    f.SliderText:SetFont(sfont,14)
    f.SliderText:SetText(L["Bidtime:"])
    f.SliderText:SetPoint("TOPLEFT", f, "TOPLEFT", 10, -85)
    f.SliderText:SetTextColor(unpack(self.colors.white))
	
--~ 	Slider
	f.timeSlider = CreateFrame("Slider", "GIA_timeSlider", f, "OptionsSliderTemplate")
    f.timeSlider:SetPoint("LEFT", f.SliderText, "RIGHT", 5, 0)
	f.timeSlider:SetWidth(f:GetWidth()-f.SliderText:GetWidth()-25)
	f.timeSlider:SetHeight(20)
	f.timeSlider:SetOrientation('HORIZONTAL')
	f.timeSlider:SetMinMaxValues(10,120)
	f.timeSlider:SetValue(dba.bidTime)
	f.timeSlider:SetValueStep(5)
	f.timeSlider:SetScript("OnValueChanged", function()
		getglobal(f.timeSlider:GetName() .. 'Text'):SetText(this:GetValue().."s")
	end)
	f.timeSlider:SetScript("OnMouseUp", function() self:SendBidTimeToAll(this:GetValue()) end)
	
	f.timeSlider.tooltipText = L["Bidtime (sec.)"]
	getglobal(f.timeSlider:GetName() .. 'Low'):SetText('10');
	getglobal(f.timeSlider:GetName() .. 'High'):SetText('120'); 
	getglobal(f.timeSlider:GetName() .. 'Text'):SetText(dba.bidTime.."s");
	
--~ Slider:GetOrientation() - Returns "HORIZONTAL" or "VERTICAL".
--~ Slider:GetThumbTexture() - Get the texture for this slider's thumb - New in 1.11.
--~ Slider:GetValue() - Get the current value of the slider.
--~ Slider:GetValueStep() - Get the current step size of the slider.
--~ Slider:SetMinMaxValues(min, max) - Set the bounds of the slider.
--~ Slider:SetOrientation("orientation") - "HORIZONTAL" or "VERTICAL".
--~ Slider:SetThumbTexture(texture or "texturePath")
--~ Slider:SetValue(value) - Set the value of the slider. Also causes the thumb to show on the first call.
--~ Slider:SetValueStep(value) - Set the step size of the slider.
	
	self:CreateBIDLISTFrame()
	
	f:Hide()
end

function GigaItemAuction:CreateBIDLISTFrame()
    
	if self.BIDLISTFrame then return end
	
	local sfont = "Interface\\AddOns\\GigaItemAuction\\textures\\FRIZQT__.TTF"
    local a = self.ADMINFrame
	local m = self.AUCTIONFrame
	
	self.BIDLISTFrame = CreateFrame("Frame", anchorAdmin.."BIDLIST", a)
    local f = self.BIDLISTFrame
	
	f.isResizing = false
	
	f:SetResizable(true)
    f:SetMovable(true)
    f:SetWidth(a:GetWidth())
    f:SetHeight(m:GetHeight()-a:GetHeight())
	f:SetMinResize(a:GetWidth(),m:GetHeight()-a:GetHeight())
    f:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background",
        edgeFile =  "Interface/Tooltips/UI-Tooltip-Border",
        edgeSize= 16, insets = { left = 0, right = 0, top = 0, bottom = 0 }}) 
    f:SetBackdropColor(unpack(self.colors.black_trans))
    f:SetBackdropBorderColor(unpack(self.colors.red_trans))
    f:ClearAllPoints()
    f:SetPoint("TOPLEFT", a, "BOTTOMLEFT")
	
--~ 	Titel
	f.Title = f:CreateFontString("GIA_Title3", "HIGH")
    f.Title:SetFont(sfont,14)
    f.Title:SetText(L["Bidlogbook"])
    f.Title:SetPoint("TOPLEFT", f, "TOPLEFT", 10, -5)
    f.Title:SetTextColor(unpack(self.colors.yellow))
	
	
    f.scroll = CreateFrame("ScrollFrame", "GIAScrollFrame", f, "UIPanelScrollFrameTemplate")
	f.scroll:SetPoint("TOPLEFT", f, "TOPLEFT", 10, -25)
	f.scroll:SetPoint("RIGHT", f, "RIGHT", -25, 0)
	f.scroll:SetPoint("BOTTOM", f, 0, 10)

	f.EditBox = CreateFrame("EditBox", "GIAEditBox", f.scroll)
	f.EditBox:SetFont(sfont,14)
	f.EditBox:SetMultiLine(true)
	f.EditBox:SetWidth(a:GetWidth()-40)
	f.EditBox:SetScript("OnEscapePressed", function() this:ClearFocus() end)
	f.EditBox:SetScript("OnTextChanged", function() f.scroll:UpdateScrollChildRect() end)
    f.EditBox:SetScript("OnEditFocusGained", function() this:ClearFocus() end)
	f.EditBox:SetText("")
	f.EditBox:SetAutoFocus(false)
	f.EditBox:ClearFocus()
	f.scroll:SetScrollChild(f.EditBox)
	
	
	f.DragRight = CreateFrame("Button", nil, f)
	f.DragRight:SetFrameLevel( f:GetFrameLevel() + 10)
	f.DragRight:SetNormalTexture("Interface\\AddOns\\GigaItemAuction\\textures\\ResizeGripRight")
	f.DragRight:SetHighlightTexture("Interface\\AddOns\\GigaItemAuction\\textures\\ResizeGripRight")
	f.DragRight:SetWidth(16)
	f.DragRight:SetHeight(16)
	f.DragRight:SetPoint("BOTTOMRIGHT", f, "BOTTOMRIGHT", 5, -5)
	f.DragRight:EnableMouse(true)
	f.DragRight:SetScript("OnMouseDown", 
        function() 
            f.isResizing = true; 
			f:StartSizing("BOTTOMRIGHT") 
        end )
	f.DragRight:SetScript("OnMouseUp", 
        function() 
            if f.isResizing == true then 
                f:StopMovingOrSizing();
				f:SetPoint("TOPLEFT", a, "BOTTOMLEFT")
                f.isResizing = false;
            end 
        end )

end


function GigaItemAuction:UpdateBidList()

	if not self:CheckPriority(PLAYERNAME) then return end
	
	local dbn = db.nowAuction
	local dbc = db.config
	local dba = db.admin
	
    local f = self.BIDLISTFrame
	local text, player, class = "", "", ""
	local cache = dbn.cache
	
	if PLAYERNAME ~= dbn.auctionAuthor then
		player, class = self:GetGuildPlayer(dbn.auctionAuthor)
		if player ~= L["unknown"] then
			text = L["onlySee"]:format("|cff"..self:GetClassHexColor(class)..player.."|r")
		else
			text = L["onlySee"]:format(dbn.auctionAuthor or L["unknown"])
		end
	elseif #cache > 0 then
		table_sort(cache,	function(w1,w2)
								if w1["BidTime"] > w2["BidTime"] then
									return true
								end
							end)
		
		for i, p in pairs(cache) do
			player, class = self:GetGuildPlayer(p.BidName)
			text = text .. "|cff555555["..getCurrentDate(p.BidTime, true).."]|r "
			text = text .. "|cff"..self:GetClassHexColor(class)
			text = text .. p.BidName.."|r "
			text = text .. p.BidPoint
			if p.BidMethod == "G" then
				text = text .. " |cff55ff55"..(p.BidArt or "X")
				text = text .. (p.BidU80 and ("|r |cffff5555("..self.BidArt.kurz[4]..")|r") or "").."|r\n"
			else
				text = text .. "|cffff5555PASS|r\n"
			end
		end
		
	end
	
	f.EditBox:SetText(text)
end
    
    
----------------------------------------------------------
--~ Show/Hide/Save Window
function GigaItemAuction:ToggleADMINFrame()
    if self.ADMINFrame:IsVisible() then
        self:HideADMINFrame()
    else
        self:ShowADMINFrame()
    end
end

function GigaItemAuction:ShowADMINFrame()
    self.ADMINFrame:Show()
    db.config.showAdminWindow = true
end

function GigaItemAuction:HideADMINFrame()
    self.ADMINFrame:Hide()
    db.config.showAdminWindow = false
end

function GigaItemAuction:ToggleBIDLISTFrame()
    if self.BIDLISTFrame:IsVisible() then
        self:HideBIDLISTFrame()
    else
        self:ShowBIDLISTFrame()
    end
end

function GigaItemAuction:ShowBIDLISTFrame()
    self.BIDLISTFrame:Show()
end

function GigaItemAuction:HideBIDLISTFrame()
    self.BIDLISTFrame:Hide()
end





------------------------------------
--~ Send Admins

function GigaItemAuction:SendAdminBreak()
	if self:CheckPriority(PLAYERNAME) then
		self:SendAddonMSG(self:Serialize(self.amsg.key.breakauction, 1))
	else
		self:Print(L["secutity3"])
	end
end

function GigaItemAuction:SendAdminResetAuction()
	if self:CheckPriority(PLAYERNAME) then
		self:SendAddonMSG(self:Serialize(self.amsg.key.sendresetauction, 1))
	else
		self:Print(L["secutity4"])
	end
end

function GigaItemAuction:SendAdminStartAuction()
	if self:CheckPriority(PLAYERNAME) then
		self:SendAddonMSG(self:Serialize(self.amsg.key.sendstartauction, 1))
	else
		self:Print(L["secutity5"])
	end
end
function GigaItemAuction:SendAdminPauseAuction()
	if self:CheckPriority(PLAYERNAME) then
		self:SendAddonMSG(self:Serialize(self.amsg.key.sendpauseauction, 1))
	else
		self:Print(L["secutity5"])
	end
end

function GigaItemAuction:SendBidTimeToAll(bidTime)
	if self:CheckPriority(PLAYERNAME) then
		self:SendAddonMSG(self:Serialize(self.amsg.key.newbidtime, bidTime), "GUILD")
	end
end

function GigaItemAuction:SendAdminAuctionLonger()
	local dbn = db.nowAuction
	if self:CheckPriority(PLAYERNAME) then
		self:AdminCurrentAuctionSend(PLAYERNAME, dbn.channel or "GUILD", "restart")
	else
		self:Print(L["secutity2"])
	end
end

function GigaItemAuction:AdminEditBidTimeByAdmin(value, author)
	if not self:CheckPriority(author) then return end
	
	local dba = db.admin
	local dbc = db.config
	
	local cauthor = self:GetColoredName(author)
	local _, _, inc_bidTime = self:Deserialize(value)
	
	dba.bidTime = tonumber(inc_bidTime)
	
	if self:CheckPriority(PLAYERNAME) then
		self.ADMINFrame.timeSlider:SetValue(dba.bidTime)
		self:Print("|cff55ff55ADMIN EDIT:|r Bidtime edit by ["..cauthor.."] to "..inc_bidTime.." sec.")
	elseif dbc.debugmodus or dbc.debugadmin then
		self:Print("|cff5555ffDEBUG:|r SET - New bidtime: "..inc_bidTime.." sec.")
	end
end

function GigaItemAuction:AdminAuctionLonger(author, auctionSTART)	
	if not self:CheckPriority(author) and not auctionSTART then return end
	
	self:SetButtonDisable()
	
	local dbn = db.nowAuction
	local dbc = db.config
	local dba = db.admin
	
	if dbc.playsound.longauction then
		PlaySound("AuctionWindowOpen")
	end
	
--~ 	gebotbuttons kurz deaktivieren
	self:GIATimerStart("SetButtonEnable","SetButtonEnable", 1)
	
--~ 	aktionsende stoppen und neu setzen
	if author == PLAYERNAME then
		self:GIATimerStart("StopAdminAuction","StopAdminAuction", dba.bidTime + 1)
	end
	self:GIATimerStart("StopAuctionButtons","SetAllButtonDisable", dba.bidTime)
	
	self:StopStatusbar()
	self:StartStatusBar()
end

function GigaItemAuction:AdminAuctionEdit(bidTime, author)
	
	self:SetButtonDisable()
	local dbn = db.nowAuction
	local dbc = db.config
	local dba = db.admin
	
	dba.bidTime = bidTime
	
--~ 	gebotbuttons kurz deaktivieren
	self:GIATimerStart("SetButtonEnable","SetButtonEnable", 1)
	
--~ 	aktionsende stoppen und neu setzen
	if author == PLAYERNAME then
		self:GIATimerStart("StopAdminAuction","StopAdminAuction", dba.bidTime + 1)
	end
	self:GIATimerStart("StopAuctionButtons","SetAllButtonDisable", dba.bidTime)
	
	self:StopStatusbar()
	self:StartStatusBar()
end

function GigaItemAuction:AdminCurrentAuctionSend(author, channel, adminValue)
	local dbc = db.config
	local dba = db.admin
	self:SendAddonMSG(self:Serialize(self.amsg.key.sendbidtime, dba.bidTime, dba.bidUP, dba.bidArt.main, dba.bidArt.second, dba.bidArt.fun, dba.bidArt.u80, dba.bidStep, adminValue and adminValue or false), channel, channel == "WHISPER" and author or nil)
	
	if dbc.debugadmin then
		self:Print("|cff5555ffDEBUG:|r |cff55ff55SEND ADMIN DATA|r - at: "..author..", ch: "..channel)
	end
end

function GigaItemAuction:AdminCurrentAuctionSync(value, author)
	if not self:CheckPriority(author) then return end
	
	local dbn = db.nowAuction
	local dbc = db.config
	local dba = db.admin
	
	local _, _, inc_bidTime, inc_bidUP, inc_bidArt_main, inc_bidArt_second, inc_bidArt_fun, inc_bidArt_u80, inc_bidStep, inc_AdminValue = self:Deserialize(value)			
	local edit = false
	
	if dbc.debugadmin then
		self:Print("|cff5555ffDEBUG:|r |cffffff55SET ADMIN DATA #1|r - bt: "..inc_bidTime..", up: "..inc_bidUP..", bs: "..inc_bidStep..", av: "..(inc_AdminValue and inc_AdminValue or "no"))
		self:Print("|cff5555ffDEBUG:|r |cffffff55SET ADMIN DATA #2|r - m: "..(inc_bidArt_main and "yes" or "no")..", s: "..(inc_bidArt_second and "yes" or "no")..", f: "..(inc_bidArt_fun and "yes" or "no")..", u80: "..(inc_bidArt_u80 and "yes" or "no"))
	end
	
	if inc_bidUP ~= dba.bidUP then
		dba.bidUP = inc_bidUP
		edit = true
	end
	if inc_bidArt_main ~= dba.bidArt.main then
		dba.bidArt.main = inc_bidArt_main
		edit = true
	end
	if inc_bidArt_second ~= dba.bidArt.second then
		dba.bidArt.second = inc_bidArt_second
		edit = true
	end
	if inc_bidArt_fun ~= dba.bidArt.fun then
		dba.bidArt.fun = inc_bidArt_fun
		edit = true
	end
	if inc_bidArt_u80 ~= dba.bidArt.u80 then
		dba.bidArt.u80 = inc_bidArt_u80
		edit = true
	end
	if inc_bidStep ~= dba.bidStep then
		dba.bidStep = inc_bidStep
		edit = true
	end
	if edit or inc_AdminValue == "restart" then
		self:SyncButtonsWithDatabase()
	end
	if inc_bidTime ~= dba.bidTime or inc_AdminValue == "restart" then
		self:AdminAuctionEdit(inc_bidTime, author)
	end
end

function GigaItemAuction:CheckPriority(player)
	local name, classconst, rankname = self:GetGuildPlayer(player)
	local rank = 12
	
	for i = 0, GuildControlGetNumRanks() do
--~ 	self:Print(i.." "..GuildControlGetRankName(i))
		if rankname == GuildControlGetRankName(i) then
			rank = i
			break
		end
    end
	
--~ 	if db.config.debugadmin then
--~ 		self:Print("|cff5555ffDEBUG:|r CP - pl:"..(player or 0) ..", nm:"..(name or 1) ..", rn:"..(rankname or 2) ..", ra:"..(rank or 3) ..", ad:"..(trueAdminRanks[rank] and "yes" or "no"))
--~ 	end
	
	if trueAdminRanks[rank] then
		return true
	else
		return false
	end
end

function GigaItemAuction:StartAdmin()
	if not self:CheckPriority(PLAYERNAME) then return end
	local dbn = db.nowAuction
	
	self:ShowADMINFrame()
	
	if dbn.auctionAuthor == PLAYERNAME then
		self:ShowBIDLISTFrame()
		self.ADMINFrame.adminButton:Enable()
	else
		self:HideBIDLISTFrame()
		self.ADMINFrame.adminButton:Disable()
	end
	self.ADMINFrame.breakButton:Enable()
	self.ADMINFrame.pauseButton:Enable()
	self.ADMINFrame.resetButton:Enable()
	self.ADMINFrame.startButton:Disable()
	self.ADMINFrame.aLongButton:Enable()
end

function GigaItemAuction:StopAdmin()
	local dbn = db.nowAuction
	local dbc = db.config
	local dba = db.admin
	
	if dbn.auctionAuthor ~= PLAYERNAME then
		self:HideADMINFrame()
		self.ADMINFrame.adminButton:Enable()
	end
	self.ADMINFrame.breakButton:Disable()
	self.ADMINFrame.pauseButton:Disable()
	self.ADMINFrame.resetButton:Disable()
	self.ADMINFrame.startButton:Disable()
	self.ADMINFrame.aLongButton:Disable()
end






